﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

public class GameManager : Manager 
{
	public static GameManager _instance;
	public GameObject _spawn;

	public Text _scoreText;

	public bool _enemyInMouth;

	public GameObject _pauseMenu;
	public GameObject _gameOverMenu;

	public GameObject _pauseButton;
	private bool _isPaused = false;

	public Canvas _canvas;

	public Text _highScore, _finalScore;
	private int _scoreValue = 0;

	private int _lifes;

	private int _kickPower;
	private float _delay;

	private int _actualLevel = 0;
	private int _previousLevel = 0;

	public GameObject[] _lives;


	void Awake()
	{
		if (_instance == null)
			_instance = this;

		//DontDestroyOnLoad (this.gameObject);
	}

	// Use this for initialization
	void Start () 
	{
		Time.timeScale = 1f;
		_lifes = 3;
		_kickPower = 2000;
		_delay = 3f;
		_muteSound = PlayerPrefsX.GetBool ("MUTESOUND", false);
		_soundButton.isOn = !_muteSound;
		base.InitSound();

		Sacrifice.OnMouthEvent += EnemyInMouth;
		InvokeRepeating ("Spawn", 0f, 3f);
	}

	private void EnemyInMouth(bool state) { _enemyInMouth = state; }

	public void UpdatePoints(int points)
	{
		_scoreValue += points;
		UpdateDifficulty ();
		_scoreText.text = _scoreValue.ToString ();
	}


	void UpdateDifficulty()
	{
		if (_scoreValue >= 10 && _actualLevel == 0)
		{
			Debug.Log ("AAS");
			RespecSpawn (3000, 3f);
			_actualLevel++;
		}

		if (_scoreValue >= 20 && _actualLevel == 1)
		{
			RespecSpawn (4000, 3f);
			_actualLevel++;
		}

		if (_scoreValue >= 30 && _actualLevel == 2)
		{
			RespecSpawn (6000, 3f);
			_actualLevel++;
		}

		if (_scoreValue >= 40 && _actualLevel == 3)
		{
			RespecSpawn (3000, 2f);
			_actualLevel++;
		}

		if (_scoreValue >= 50 && _actualLevel == 4)
		{
			RespecSpawn (5000, 2f);
			_actualLevel++;
		}


	}

	void RespecSpawn(int kickPower, float delay)
	{
		CancelInvoke ();
		_kickPower = kickPower;
		InvokeRepeating("Spawn",0, _delay);
	}

	void Spawn()
	{
		GameObject minion;
		int type = Random.Range (0, 3);
		if ((TYPE)type == TYPE.TOURIST) 
		{
			int skin = Random.Range (0, 2);
			minion = Instantiate (Resources.Load ("Prefabs/Sacrifice_" + type.ToString() + "_" + skin.ToString())) as GameObject;
		} 

		else minion = Instantiate (Resources.Load ("Prefabs/Sacrifice_" + type.ToString())) as GameObject;
		minion.GetComponent<Sacrifice> ().Type = (TYPE)type;
		minion.transform.SetParent (_spawn.transform, false);
		minion.transform.position = _spawn.transform.position;
		minion.GetComponent<Sacrifice> ().KickOut (_kickPower);
	}

	public void DecrementLifes()
	{
		_lifes--;
		_lives [_lifes].SetActive (false);
		if (_lifes > 0)
			Debug.Log ("UpdatesLives");
		else
			GoToGameOver ();
	}

	public void UpdateLives()
	{
		
	}

	public void PressedScreen()
	{
		if (_isPaused)
			return; 

		HardCodedAnimatorUI._instance.HardAnimate ();
		HardCodedAudioManager._instance.SwapClips (SFX.EAT);
		_sfx.Play ();

		if (!_enemyInMouth)
			DecrementLifes ();
		else _spawn.BroadcastMessage ("Eat");
	}
		
	// Update is called once per frame
	void Update () { }

	public void GoToPause()
	{
		if (_gameOverMenu.activeInHierarchy)
			return;

		if (!_isPaused) {	
			_isPaused = true;
			Time.timeScale = 0f;
			_pauseMenu.SetActive (_isPaused);

		} else
			Resume ();
	}

	public void Resume()
	{
		_isPaused = false;
		Time.timeScale = 1f;
		_pauseMenu.SetActive (_isPaused);
	}

	public void Restart()  { base.LoadScene ("Game"); }

	public void Quit() { base.LoadScene ("MainMenu"); }

	public void GoToGameOver()
	{	
		_pauseButton.SetActive (false);
		_gameOverMenu.SetActive (true);
		int score = _scoreValue;
		int highscore = PlayerPrefs.GetInt ("HIGHSCORE", 0);

		_finalScore.text =_scoreValue.ToString ();

	if (score > highscore){
		PlayerPrefs.SetInt ("HIGHSCORE", score);
		_highScore.text = score.ToString ();
		}
		else{
			_highScore.text =  highscore.ToString ();

	}
	}
}